##  Description
Typically, management stakeholders use something besides EA-specific terminology and concepts, such as business capabilities or applications. They instead speak of platforms as a broader category of summarizing IT/tech-related elements that support their business model. Platforms also reflect a standard used within the company, and can be leveraged to maintain that standard and ensure that it is being used.
The modeling of platforms in SAP LeanIX helps connect fact sheet types like IT components and applications to a concept understood and used by the C-level. It provides CIOs with insights on critical components supporting the organization’s platforms, e.g., which applications or microservices are consuming the platform (e.g., via APIs to microservices) and which users/processes are backed by platform offerings vs. not as part of a transformation.
If your organization uses platforms as a strategically relevant concept, modeling those in SAP LeanIX will increase the impact of your EA work.
Overview of all relations to/from platform:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747c1177a4410148d49c93094edb19e_LowRes.png)
Platform examples:
  * Business platform: B2B e-commerce platform for partners
  * IT platform: SAP BTP for e-commerce services
